@@ -150,8 +150,8 @@ struct _GtkSourceCompletionPrivate
 
 	/* List of proposals */
 	GtkTreeView *tree_view_proposals;
-	GtkTreeViewColumn *tree_view_column_accelerator;
-	GtkCellRenderer *cell_renderer_icon;
+
+	GtkCellRenderer *cell_renderer_proposal;
 
 	/* Completion management */
 
@@ -463,17 +463,6 @@ update_window_position (GtkSourceCompletion *completion)
 	                                         &iter);
 }
 
-static void
-update_tree_view_visibility (GtkSourceCompletion *completion)
-{
-	gtk_tree_view_column_set_visible (completion->priv->tree_view_column_accelerator,
-	                                  completion->priv->num_accelerators > 0);
-
-	g_object_set (completion->priv->cell_renderer_icon,
-	              "visible", completion->priv->show_icons,
-	              NULL);
-}
-
 static void
 set_info_widget (GtkSourceCompletion *completion,
 		 GtkWidget           *new_widget)
@@ -582,6 +571,52 @@ gtk_source_completion_hide_default (GtkSourceCompletion *completion)
 	gtk_widget_hide (GTK_WIDGET (completion->priv->main_window));
 }
 
+static void
+gtk_source_completion_proposals_size_allocate (GtkSourceCompletion *completion,
+					       GtkAllocation       *allocation,
+					       GtkWidget           *widget)
+{
+	GtkTreeViewColumn *column;
+	gint cell_offset = 0;
+	gint column_offset;
+	gint focus_padding;
+	gint horizontal_separator;
+	gint x_offset = 0;
+
+	if (!gtk_widget_get_realized (GTK_WIDGET (completion->priv->tree_view_proposals)))
+	{
+		return;
+	}
+
+	gtk_widget_style_get (GTK_WIDGET (completion->priv->tree_view_proposals),
+	                      "focus-padding", &focus_padding,
+	                      "horizontal-separator", &horizontal_separator,
+	                      NULL);
+
+	column = gtk_tree_view_get_column (completion->priv->tree_view_proposals, 1);
+	column_offset = gtk_tree_view_column_get_x_offset (column);
+	gtk_tree_view_column_cell_get_position (column,
+	                                        completion->priv->cell_renderer_proposal,
+	                                        &cell_offset,
+	                                        NULL);
+
+	x_offset = column_offset + cell_offset + horizontal_separator + focus_padding;
+
+	gtk_tree_view_convert_bin_window_to_widget_coords (completion->priv->tree_view_proposals,
+	                                                   x_offset,
+	                                                   0,
+	                                                   &x_offset,
+	                                                   NULL);
+	gtk_widget_translate_coordinates (GTK_WIDGET (completion->priv->tree_view_proposals),
+	                                  GTK_WIDGET (completion->priv->main_window),
+	                                  x_offset,
+	                                  0,
+	                                  &x_offset,
+	                                  NULL);
+
+	_gtk_source_completion_info_set_xoffset (completion->priv->main_window, -x_offset);
+}
+
 static void
 gtk_source_completion_activate_proposal (GtkSourceCompletion *completion)
 {
@@ -1457,6 +1492,21 @@ update_bottom_bar_visibility (GtkSourceCompletion *completion)
 	}
 }
 
+static void
+style_context_changed (GtkStyleContext     *style_context,
+		       GtkSourceCompletion *completion)
+{
+	PangoFontDescription *font_desc = NULL;
+
+	gtk_style_context_get (style_context, GTK_STATE_FLAG_NORMAL,
+			       GTK_STYLE_PROPERTY_FONT, &font_desc,
+			       NULL);
+	g_object_set (completion->priv->cell_renderer_proposal,
+		      "font-desc", font_desc,
+		      NULL);
+	pango_font_description_free (font_desc);
+}
+
 static void
 populating_done (GtkSourceCompletion        *completion,
                  GtkSourceCompletionContext *context)
@@ -1521,6 +1571,7 @@ static void
 connect_view (GtkSourceCompletion *completion)
 {
 	GtkTextBuffer *buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (completion->priv->view));
+	GtkStyleContext *style_context = gtk_widget_get_style_context (GTK_WIDGET (completion->priv->view));
 
 	g_signal_connect_object (completion->priv->view,
 				 "focus-out-event",
@@ -1595,6 +1646,14 @@ connect_view (GtkSourceCompletion *completion)
 					 G_CALLBACK (buffer_insert_text_cb),
 					 completion,
 					 G_CONNECT_AFTER);
+
+	g_signal_connect_object (style_context,
+				 "changed",
+				 G_CALLBACK (style_context_changed),
+				 completion,
+				 G_CONNECT_AFTER);
+
+	style_context_changed (style_context, completion);
 }
 
 static void
@@ -1680,13 +1739,9 @@ gtk_source_completion_set_property (GObject      *object,
 			break;
 		case PROP_SHOW_ICONS:
 			completion->priv->show_icons = g_value_get_boolean (value);
-
-			update_tree_view_visibility (completion);
 			break;
 		case PROP_ACCELERATORS:
 			completion->priv->num_accelerators = g_value_get_uint (value);
-
-			update_tree_view_visibility (completion);
 			break;
 		case PROP_AUTO_COMPLETE_DELAY:
 			completion->priv->auto_complete_delay = g_value_get_uint (value);
@@ -2143,14 +2198,21 @@ selection_func (GtkTreeSelection    *selection,
 	}
 }
 
+static void
+accelerators_notify_cb (GtkSourceCompletion *completion,
+			GParamSpec          *pspec,
+			GtkTreeViewColumn   *column)
+{
+	gtk_tree_view_column_set_visible (column, completion->priv->num_accelerators > 0);
+}
+
 static void
 init_tree_view (GtkSourceCompletion *completion,
 		GtkBuilder          *builder)
 {
 	GtkTreeSelection *selection;
 	GtkTreeViewColumn *column;
-	GtkCellRenderer *cell_renderer_proposal;
-	GtkCellRenderer *cell_renderer_accelerator;
+	GtkCellRenderer *cell_renderer;
 	GtkStyleContext *style_context;
 	GdkRGBA background_color;
 	GdkRGBA foreground_color;
@@ -2162,6 +2224,11 @@ init_tree_view (GtkSourceCompletion *completion,
 				  G_CALLBACK (gtk_source_completion_activate_proposal),
 				  completion);
 
+	g_signal_connect_swapped (completion->priv->tree_view_proposals,
+				  "size-allocate",
+				  G_CALLBACK (gtk_source_completion_proposals_size_allocate),
+				  completion);
+
 	/* Selection */
 
 	selection = gtk_tree_view_get_selection (completion->priv->tree_view_proposals);
@@ -2178,11 +2245,11 @@ init_tree_view (GtkSourceCompletion *completion,
 
 	/* Icon cell renderer */
 
-	completion->priv->cell_renderer_icon = GTK_CELL_RENDERER (gtk_builder_get_object (builder, "cell_renderer_icon"));
+	cell_renderer = GTK_CELL_RENDERER (gtk_builder_get_object (builder, "cell_renderer_icon"));
 
-	column = GTK_TREE_VIEW_COLUMN (gtk_builder_get_object (builder, "tree_view_column_proposal"));
+	column = GTK_TREE_VIEW_COLUMN (gtk_builder_get_object (builder, "tree_view_column_icon"));
 
-	gtk_tree_view_column_set_attributes (column, completion->priv->cell_renderer_icon,
+	gtk_tree_view_column_set_attributes (column, cell_renderer,
 					     "pixbuf", GTK_SOURCE_COMPLETION_MODEL_COLUMN_ICON,
 					     "cell-background-set", GTK_SOURCE_COMPLETION_MODEL_COLUMN_IS_HEADER,
 					     NULL);
@@ -2192,15 +2259,22 @@ init_tree_view (GtkSourceCompletion *completion,
 	                                        GTK_STATE_FLAG_INSENSITIVE,
 	                                        &background_color);
 
-	g_object_set (completion->priv->cell_renderer_icon,
+	g_object_set (cell_renderer,
 	              "cell-background-rgba", &background_color,
 	              NULL);
 
+	g_object_bind_property (completion, "show-icons",
+				cell_renderer, "visible",
+				G_BINDING_SYNC_CREATE);
+
 	/* Proposal text cell renderer */
 
-	cell_renderer_proposal = GTK_CELL_RENDERER (gtk_builder_get_object (builder, "cell_renderer_proposal"));
+	cell_renderer = GTK_CELL_RENDERER (gtk_builder_get_object (builder, "cell_renderer_proposal"));
+	completion->priv->cell_renderer_proposal = cell_renderer;
 
-	gtk_tree_view_column_set_attributes (column, cell_renderer_proposal,
+	column = GTK_TREE_VIEW_COLUMN (gtk_builder_get_object (builder, "tree_view_column_proposal"));
+
+	gtk_tree_view_column_set_attributes (column, cell_renderer,
 					     "markup", GTK_SOURCE_COMPLETION_MODEL_COLUMN_MARKUP,
 					     "cell-background-set", GTK_SOURCE_COMPLETION_MODEL_COLUMN_IS_HEADER,
 					     "foreground-set", GTK_SOURCE_COMPLETION_MODEL_COLUMN_IS_HEADER,
@@ -2210,35 +2284,38 @@ init_tree_view (GtkSourceCompletion *completion,
 	                             GTK_STATE_FLAG_INSENSITIVE,
 	                             &foreground_color);
 
-	g_object_set (cell_renderer_proposal,
+	g_object_set (cell_renderer,
 	              "foreground-rgba", &foreground_color,
 	              "cell-background-rgba", &background_color,
 	              NULL);
 
 	/* Accelerators cell renderer */
 
-	completion->priv->tree_view_column_accelerator =
-		GTK_TREE_VIEW_COLUMN (gtk_builder_get_object (builder, "tree_view_column_accelerator"));
+	column = GTK_TREE_VIEW_COLUMN (gtk_builder_get_object (builder, "tree_view_column_accelerator"));
 
-	cell_renderer_accelerator = GTK_CELL_RENDERER (gtk_builder_get_object (builder, "cell_renderer_accelerator"));
+	cell_renderer = GTK_CELL_RENDERER (gtk_builder_get_object (builder, "cell_renderer_accelerator"));
 
-	gtk_tree_view_column_set_attributes (completion->priv->tree_view_column_accelerator,
-					     cell_renderer_accelerator,
+	gtk_tree_view_column_set_attributes (column,
+					     cell_renderer,
 					     "cell-background-set", GTK_SOURCE_COMPLETION_MODEL_COLUMN_IS_HEADER,
 					     NULL);
 
-	g_object_set (cell_renderer_accelerator,
+	g_object_set (cell_renderer,
 	              "foreground-rgba", &foreground_color,
 	              "cell-background-rgba", &background_color,
 		      NULL);
 
-	gtk_tree_view_column_set_cell_data_func (completion->priv->tree_view_column_accelerator,
-	                                         cell_renderer_accelerator,
+	gtk_tree_view_column_set_cell_data_func (column,
+	                                         cell_renderer,
 	                                         (GtkTreeCellDataFunc)render_proposal_accelerator_func,
 	                                         completion,
 	                                         NULL);
 
-	update_tree_view_visibility (completion);
+	g_signal_connect_object (completion,
+				 "notify::accelerators",
+				 G_CALLBACK (accelerators_notify_cb),
+				 column,
+				 0);
 }
 
 static void
