@@ -65,6 +65,8 @@ struct _GtkSourceCompletionInfoPrivate
 
 	GtkWidget *attached_to;
 	gulong focus_out_event_handler;
+
+	gint xoffset;
 };
 
 /* Signals */
@@ -327,6 +329,15 @@ gtk_source_completion_info_class_init (GtkSourceCompletionInfoClass *klass)
 		              0);
 }
 
+void
+_gtk_source_completion_info_set_xoffset (GtkSourceCompletionInfo *window,
+					 gint                     xoffset)
+{
+	g_return_if_fail (GTK_SOURCE_IS_COMPLETION_INFO (window));
+
+	window->priv->xoffset = xoffset;
+}
+
 /* Move to iter */
 
 static void
@@ -450,6 +461,8 @@ move_to_iter (GtkSourceCompletionInfo *window,
 	get_iter_pos (view, iter, &x, &y, &height);
 	gtk_window_get_size (GTK_WINDOW (window), &w, &h);
 
+	x += window->priv->xoffset;
+
 	oy = y;
 	compensate_for_gravity (window, &cx, &cy, w, h);
 
