@@ -19,16 +19,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "gtksourcesearchsettings.h"
 #include "gtksourceview-i18n.h"
 
 /**
  * SECTION:searchsettings
- * @Short_description: Search settings
+ * @Short_description: The settings of a search
  * @Title: GtkSourceSearchSettings
  * @See_also: #GtkSourceSearchContext
  *
@@ -123,7 +119,8 @@ gtk_source_search_settings_set_property (GObject      *object,
 	switch (prop_id)
 	{
 		case PROP_SEARCH_TEXT:
-			gtk_source_search_settings_set_search_text (settings, g_value_get_string (value));
+			g_free (settings->priv->search_text);
+			settings->priv->search_text = g_value_dup_string (value);
 			break;
 
 		case PROP_CASE_SENSITIVE:
@@ -169,8 +166,8 @@ gtk_source_search_settings_class_init (GtkSourceSearchSettingsClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_SEARCH_TEXT,
 					 g_param_spec_string ("search-text",
-							      "Search text",
-							      "The text to search",
+							      _("Search text"),
+							      _("The text to search"),
 							      NULL,
 							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
@@ -184,8 +181,8 @@ gtk_source_search_settings_class_init (GtkSourceSearchSettingsClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_CASE_SENSITIVE,
 					 g_param_spec_boolean ("case-sensitive",
-							       "Case sensitive",
-							       "Case sensitive",
+							       _("Case sensitive"),
+							       _("Case sensitive"),
 							       FALSE,
 							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
@@ -200,8 +197,8 @@ gtk_source_search_settings_class_init (GtkSourceSearchSettingsClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_AT_WORD_BOUNDARIES,
 					 g_param_spec_boolean ("at-word-boundaries",
-							       "At word boundaries",
-							       "Search at word boundaries",
+							       _("At word boundaries"),
+							       _("Search at word boundaries"),
 							       FALSE,
 							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
@@ -217,9 +214,9 @@ gtk_source_search_settings_class_init (GtkSourceSearchSettingsClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_WRAP_AROUND,
 					 g_param_spec_boolean ("wrap-around",
-							       "Wrap around",
-							       "Wrap around",
-							       FALSE,
+							       _("Wrap around"),
+							       _("Wrap around"),
+							       TRUE,
 							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
 	/**
@@ -233,8 +230,8 @@ gtk_source_search_settings_class_init (GtkSourceSearchSettingsClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_REGEX_ENABLED,
 					 g_param_spec_boolean ("regex-enabled",
-							       "Regex enabled",
-							       "Whether to search by regular expression",
+							       _("Regex enabled"),
+							       _("Whether to search by regular expression"),
 							       FALSE,
 							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
@@ -310,7 +307,7 @@ gtk_source_search_settings_set_search_text (GtkSourceSearchSettings *settings,
  * You may be interested to call gtk_source_utils_escape_search_text() after
  * this function.
  *
- * Returns: (nullable): the text to search, or %NULL if the search is disabled.
+ * Returns: the text to search, or %NULL if the search is disabled.
  * Since: 3.10
  */
 const gchar *
